@@ -4,9 +4,11 @@
 // Decomp is distributed under the Common Public License as part of the      //
 // COIN-OR repository (http://www.coin-or.org).                              //
 //                                                                           //
-// Author: Matthew Galati, Lehigh University                                 //
+// Authors: Matthew Galati, SAS Institute Inc. (matthew.galati@sas.com)      //
+//          Ted Ralphs, Lehigh University (ted@lehigh.edu)                   //
+//          Jiadong Wang, Lehigh University (jiw408@lehigh.edu)              //
 //                                                                           //
-// Copyright (C) 2002-2013, Lehigh University, Matthew Galati, and Ted Ralphs//
+// Copyright (C) 2002-2015, Lehigh University, Matthew Galati, and Ted Ralphs//
 // All Rights Reserved.                                                      //
 //===========================================================================//
 
@@ -65,14 +67,14 @@ int main(int argc, char** argv)
       //--- create the CPM algorithm object
       //---
       if (doCut) {
-         algo = new DecompAlgoC(&gap, &utilParam);
+         algo = new DecompAlgoC(&gap, utilParam);
       }
 
       //---
       //--- create the PC algorithm object
       //---
       if (doPriceCut) {
-         algo = new DecompAlgoPC(&gap, &utilParam);
+         algo = new DecompAlgoPC(&gap, utilParam);
       }
 
       if (doCut && doDirect) {
