@@ -4,9 +4,11 @@
 // Decomp is distributed under the Common Public License as part of the      //
 // COIN-OR repository (http://www.coin-or.org).                              //
 //                                                                           //
-// Author: Matthew Galati, Lehigh University                                 //
+// Authors: Matthew Galati, SAS Institute Inc. (matthew.galati@sas.com)      //
+//          Ted Ralphs, Lehigh University (ted@lehigh.edu)                   //
+//          Jiadong Wang, Lehigh University (jiw408@lehigh.edu)              //
 //                                                                           //
-// Copyright (C) 2002-2013, Lehigh University, Matthew Galati, and Ted Ralphs//
+// Copyright (C) 2002-2015, Lehigh University, Matthew Galati, and Ted Ralphs//
 // All Rights Reserved.                                                      //
 //===========================================================================//
 
@@ -15,18 +17,11 @@
 #include "MILPBlock_DecompApp.h"
 
 //===========================================================================//
-void MILPBlock_DecompApp::initializeApp(UtilParameters & utilParam)  {
+void MILPBlock_DecompApp::initializeApp()  {
    
    UtilPrintFuncBegin(m_osLog, m_classTag,
 		      "initializeApp()", m_appParam.LogLevel, 2);
    
-   //---
-   //--- get application parameters
-   //---   
-   m_appParam.getSettings(utilParam);   
-   if(m_appParam.LogLevel >= 1)
-      m_appParam.dumpSettings();
-
    //---
    //--- read MILPBlock instance (mps format)
    //---
@@ -291,16 +286,18 @@ void MILPBlock_DecompApp::readInitSolutionFile(DecompVarList & initVars){
    for(mit = m_modelR.begin(); mit != m_modelR.end(); mit++){
       int                   blockIndex = mit->first;
       DecompConstraintSet * model      = mit->second;
+      /*
       if(model->m_masterOnly){         
          colIndexToBlockIndex.insert(make_pair(model->m_masterOnlyIndex,
                                                blockIndex));
       }
-      else{         
+      else
+      */{         
          const vector<int> & activeColumns = model->getActiveColumns();
          vector<int>::const_iterator vit;
          for(vit = activeColumns.begin(); vit != activeColumns.end(); vit++){
             colIndexToBlockIndex.insert(make_pair(*vit, blockIndex));
-         }
+	 }
       }
    }
 
@@ -335,7 +332,8 @@ void MILPBlock_DecompApp::readInitSolutionFile(DecompVarList & initVars){
       colIndex        = colNameToIndex[colName];
       blockIndex      = colIndexToBlockIndex[colIndex];
       DecompConstraintSet * model = m_modelR[blockIndex];
-      if(model->m_masterOnly){
+
+      /*      if(model->m_masterOnly){
          printf("MasterOnly col=%s value=%g lb=%g ub=%g",
                 colName.c_str(), colValue, colLB[colIndex], colUB[colIndex]);
          if(colValue < (colUB[colIndex]-1.0e-5) &&
@@ -344,7 +342,8 @@ void MILPBlock_DecompApp::readInitSolutionFile(DecompVarList & initVars){
             //TODO: if so, should add both lb and ub
          }
          printf("\n");
-      }
+	 }*/
+
       pair<int,int> p = make_pair(solutionIndex, blockIndex);
       it = varTemp.find(p);
       if(it == varTemp.end()){         
@@ -379,7 +378,7 @@ void MILPBlock_DecompApp::readInitSolutionFile(DecompVarList & initVars){
                                       origCost);
       var->setBlockId(indexPair.second);
 
-      var->print(m_osLog, colNames);
+      var->print(m_infinity, m_osLog, colNames);
 
       initVars.push_back(var);
       printf("Adding initial variable with origCost = %g\n", origCost);
@@ -414,6 +413,7 @@ MILPBlock_DecompApp::findActiveColumns(const vector<int> & rowsPart,
 }
 
 //===========================================================================//
+/*
 void
 MILPBlock_DecompApp::createModelMasterOnlys(vector<int> & masterOnlyCols){
 
@@ -477,7 +477,7 @@ MILPBlock_DecompApp::createModelMasterOnlys(vector<int> & masterOnlyCols){
 
    return;   
 }
-
+*/
 //===========================================================================//
 void
 MILPBlock_DecompApp::createModelPart(DecompConstraintSet * model,
@@ -746,7 +746,7 @@ void MILPBlock_DecompApp::createModels(){
       for(i = 0; i < nCols; i++)
 	 m_objective[i] *= -1;
    }
-   setModelObjective(m_objective);
+   setModelObjective(m_objective, nCols);
 
    //---
    //--- Construct the core matrix.
@@ -867,7 +867,7 @@ void MILPBlock_DecompApp::createModels(){
    //---   we will make column bounds explicity rows
    //---
    ///////////STOP - don't need anymore if DECOMP_MASTERONLY_DIRECT
-#if 1
+#if 0
    int nMasterOnlyCols = static_cast<int>(modelCore->masterOnlyCols.size());
    if(nMasterOnlyCols){
       if(m_appParam.LogLevel >= 1)
