@@ -4,9 +4,11 @@
 // Decomp is distributed under the Common Public License as part of the      //
 // COIN-OR repository (http://www.coin-or.org).                              //
 //                                                                           //
-// Author: Matthew Galati, Lehigh University                                 //
+// Authors: Matthew Galati, SAS Institute Inc. (matthew.galati@sas.com)      //
+//          Ted Ralphs, Lehigh University (ted@lehigh.edu)                   //
+//          Jiadong Wang, Lehigh University (jiw408@lehigh.edu)              //
 //                                                                           //
-// Copyright (C) 2002-2007, Lehigh University, Matthew Galati, and Ted Ralphs//
+// Copyright (C) 2002-2015, Lehigh University, Matthew Galati, and Ted Ralphs//
 // All Rights Reserved.                                                      //
 //===========================================================================//
 
@@ -360,7 +362,8 @@ class VRP_Concorde {
    }
 
    int solveTSP(vector<int>    & vrpRouteInd,
-		vector<double> & vrpRouteEls){
+		vector<double> & vrpRouteEls,
+		double infinity){
 
 
       //---
@@ -421,8 +424,8 @@ class VRP_Concorde {
       int    nRoutes    = m_vrp->m_numRoutes;      
       int    nOrigVerts = graphLib.n_vertices;
       int    nCustomers = nOrigVerts - 1;
-      double upbound    = DecompInf;
-      double optval     = DecompInf;      
+      double upbound    = infinity;
+      double optval     = infinity;      
 
       //---
       //--- try tiny first, switch if needed... if fails
