@@ -4,12 +4,11 @@
 // DIP is distributed under the Eclipse Public License as part of the        //
 // COIN-OR repository (http://www.coin-or.org).                              //
 //                                                                           //
-// Author: Matthew Galati, SAS Institute Inc. (matthew.galati@sas.com)       //
+// Authors: Matthew Galati, SAS Institute Inc. (matthew.galati@sas.com)      //
+//          Ted Ralphs, Lehigh University (ted@lehigh.edu)                   //
+//          Jiadong Wang, Lehigh University (jiw408@lehigh.edu)              //
 //                                                                           //
-// Conceptual Design: Matthew Galati, SAS Institute Inc.                     //
-//                    Ted Ralphs, Lehigh University                          //
-//                                                                           //
-// Copyright (C) 2002-2013, Lehigh University, Matthew Galati, Ted Ralphs    //
+// Copyright (C) 2002-2015, Lehigh University, Matthew Galati, Ted Ralphs    //
 // All Rights Reserved.                                                      //
 //===========================================================================//
 
@@ -133,8 +132,8 @@ int AlpsDecompTreeNode::process(bool isRoot,
    double currentUB       = getKnowledgeBroker()->getIncumbentValue();
    double parentObjValue  = getQuality();
    double primalTolerance = 1.0e-6;
-   double globalLB        = -DecompInf;
-   double globalUB        =  DecompInf;
+   double globalLB        = -decompAlgo->getInfinity();
+   double globalUB        =  decompAlgo->getInfinity();
    double thisQuality;
    AlpsTreeNode*         bestNode  = NULL;
    const double*         lbs       = desc->lowerBounds_;
@@ -225,8 +224,8 @@ int AlpsDecompTreeNode::process(bool isRoot,
          double* ubsInf = new double[n_cols];
 
          for (c = 0; c < n_cols; c++) {
-            lbsInf[c] = -DecompInf;
-            ubsInf[c] =  DecompInf;
+            lbsInf[c] = -decompAlgo->getInfinity();
+            ubsInf[c] =  decompAlgo->getInfinity();
             //printf("root c:%d lb=%g ub=%g\n",
             //   c, lbs[c], ubs[c]);
          }
@@ -244,7 +243,7 @@ int AlpsDecompTreeNode::process(bool isRoot,
    //---
    currentUB = getKnowledgeBroker()->getIncumbentValue();
    decompAlgo->setObjBoundIP(currentUB);//??
-   gap      = DecompInf;
+   gap      = decompAlgo->getInfinity();
    globalUB = getKnowledgeBroker()->getIncumbentValue();
 
    if (!isRoot) {
@@ -254,7 +253,7 @@ int AlpsDecompTreeNode::process(bool isRoot,
       //--- if the overall gap is tight enough, fathom whatever is left
       //---
       //TODO: cutoffIncrement (currentUB-cutoffIncrement)
-      gap = UtilCalculateGap(globalLB, globalUB);
+      gap = UtilCalculateGap(globalLB, globalUB, decompAlgo->getInfinity());
 
       if (gap <= relTolerance) {
          doFathom = true;
@@ -304,7 +303,7 @@ int AlpsDecompTreeNode::process(bool isRoot,
       }
 
       //watch tolerance here... if quality is close enough, fathom it
-      gap = UtilCalculateGap(thisQuality, currentUB);
+      gap = UtilCalculateGap(thisQuality, currentUB, decompAlgo->getInfinity());
 
       //if(gap <= relTolerance){
       if (quality_ >= currentUB) {
@@ -366,7 +365,9 @@ TERM_PROCESS:
       setStatus(AlpsNodeStatusFathomed);
    } else {
       status = chooseBranchingObject(model);
-      decompAlgo->postProcessBranch(decompStatus);
+      if (getStatus() == AlpsNodeStatusPregnant){
+	 decompAlgo->postProcessBranch(decompStatus);
+      }
    }
 
    UtilPrintFuncEnd(&cout, m_classTag,
@@ -505,24 +506,24 @@ AlpsDecompTreeNode::branch()
 
    if (decompParam.BranchStrongIter) {
       double globalUB             = getKnowledgeBroker()->getIncumbentValue();
-      int    solveMasterAsIp      = decompParam.SolveMasterAsIp;
-      int    limitTotalCutIters   = decompParam.LimitTotalCutIters;
-      int    limitTotalPriceIters = decompParam.LimitTotalPriceIters;
+      int    solveMasterAsMip      = decompParam.SolveMasterAsMip;
+      int    limitTotalCutIters   = decompParam.TotalCutItersLimit;
+      int    limitTotalPriceIters = decompParam.TotalPriceItersLimit;
       //---
       //--- calculate an estimate on the lower bound after branching
       //---
-      //decompParam.LimitTotalCutIters   = decompParam.BranchStrongIter;
-      decompParam.LimitTotalCutIters   = 0;
-      decompParam.LimitTotalPriceIters = decompParam.BranchStrongIter;
-      decompParam.SolveMasterAsIp      = 0;
+      //decompParam.TotalCutItersLimit   = decompParam.BranchStrongIter;
+      decompParam.TotalCutItersLimit   = 0;
+      decompParam.TotalPriceItersLimit = decompParam.BranchStrongIter;
+      decompParam.SolveMasterAsMip      = 0;
       decompAlgo->setStrongBranchIter(true);
       decompAlgo->setMasterBounds(newLbs, newUbs);
       decompAlgo->setSubProbBounds(newLbs, newUbs);
       decompAlgo->processNode(this, objVal, globalUB);
       decompAlgo->setStrongBranchIter(false);
-      decompParam.LimitTotalCutIters   = limitTotalCutIters;
-      decompParam.LimitTotalPriceIters = limitTotalPriceIters;
-      decompParam.SolveMasterAsIp      = solveMasterAsIp;
+      decompParam.TotalCutItersLimit   = limitTotalCutIters;
+      decompParam.TotalPriceItersLimit = limitTotalPriceIters;
+      decompParam.SolveMasterAsMip      = solveMasterAsMip;
       //TOOD: what if it stops in Phase1
       //how will this work in CPM?
    }
@@ -569,24 +570,24 @@ AlpsDecompTreeNode::branch()
 
    if (decompParam.BranchStrongIter) {
       double globalUB             = getKnowledgeBroker()->getIncumbentValue();
-      int    solveMasterAsIp      = decompParam.SolveMasterAsIp;
-      int    limitTotalCutIters   = decompParam.LimitTotalCutIters;
-      int    limitTotalPriceIters = decompParam.LimitTotalPriceIters;
+      int    solveMasterAsMip      = decompParam.SolveMasterAsMip;
+      int    limitTotalCutIters   = decompParam.TotalCutItersLimit;
+      int    limitTotalPriceIters = decompParam.TotalPriceItersLimit;
       //---
       //--- calculate an estimate on the lower bound after branching
       //---
-      //decompParam.LimitTotalCutIters   = decompParam.BranchStrongIter;
-      decompParam.LimitTotalCutIters   = 0;
-      decompParam.LimitTotalPriceIters = decompParam.BranchStrongIter;
-      decompParam.SolveMasterAsIp      = 0;
+      //decompParam.TotalCutItersLimit   = decompParam.BranchStrongIter;
+      decompParam.TotalCutItersLimit   = 0;
+      decompParam.TotalPriceItersLimit = decompParam.BranchStrongIter;
+      decompParam.SolveMasterAsMip      = 0;
       decompAlgo->setStrongBranchIter(true);
       decompAlgo->setMasterBounds(newLbs, newUbs);
       decompAlgo->setSubProbBounds(newLbs, newUbs);
       decompAlgo->processNode(this, objVal, globalUB);
       decompAlgo->setStrongBranchIter(false);
-      decompParam.LimitTotalCutIters   = limitTotalCutIters;
-      decompParam.LimitTotalPriceIters = limitTotalPriceIters;
-      decompParam.SolveMasterAsIp      = solveMasterAsIp;
+      decompParam.TotalCutItersLimit   = limitTotalCutIters;
+      decompParam.TotalPriceItersLimit = limitTotalPriceIters;
+      decompParam.SolveMasterAsMip      = solveMasterAsMip;
    }
 
    newNodes.push_back(CoinMakeTriple(static_cast<AlpsNodeDesc*>(child),
