@@ -4,9 +4,11 @@
 // Decomp is distributed under the Common Public License as part of the      //
 // COIN-OR repository (http://www.coin-or.org).                              //
 //                                                                           //
-// Author: Matthew Galati, Lehigh University                                 //
+// Authors: Matthew Galati, SAS Institute Inc. (matthew.galati@sas.com)      //
+//          Ted Ralphs, Lehigh University (ted@lehigh.edu)                   //
+//          Jiadong Wang, Lehigh University (jiw408@lehigh.edu)              //
 //                                                                           //
-// Copyright (C) 2002-2013, Lehigh University, Matthew Galati, and Ted Ralphs//
+// Copyright (C) 2002-2015, Lehigh University, Matthew Galati, and Ted Ralphs//
 // All Rights Reserved.                                                      //
 //===========================================================================//
 
@@ -38,49 +40,55 @@ void DecompAuto(DecompApp milp,
                 DecompMainParam& decompMainParam);
 
 DecompSolverResult* solveDirect(const DecompApp& decompApp);
+
 //===========================================================================//
+
 int main(int argc, char** argv)
 {
    try {
-      //---
-      //--- create the utility class for parsing parameters
-      //---
-      UtilParameters utilParam(argc, argv);
-      DecompMainParam decompMainParam;
+
       UtilTimer timer;
+      std::vector<int> blockNumCandidates;
+      DecompMainParam decompMainParam;
       decompMainParam.timeSetupReal = 0.0;
       decompMainParam.timeSetupCpu  = 0.0;
       decompMainParam.timeSolveReal = 0.0;
       decompMainParam.timeSolveCpu  = 0.0;
+
+      //---
+      //--- Parse cpmmand line and store parameters
+      //---
+      UtilParameters utilParam(argc, argv);
+
       //---
       //--- start overall timer
       //---
       timer.start();
-      DecompApp milp;
+
       //---
-      //--- put the one of the functions in the constructor into the main
+      //--- construct the instance
       //---
-      std::vector<int> blockNumCandidates;
-      milp.startupLog();
+      DecompApp milp(utilParam);
+
       // get the current working Directory.
       char the_path[256];
-      std::string path(getcwd(the_path, 255));
-      milp.m_param.CurrentWorkingDir = path;
-
+      milp.m_param.CurrentWorkingDir = std::string(getcwd(the_path, 255));
       if (milp.m_param.LogDebugLevel >= 1) {
-         std::cout << path << std::endl;
          std::cout << milp.m_param.CurrentWorkingDir << std::endl;
       }
 
-      const CoinPackedMatrix* m_matrix = milp.readProblem(utilParam);
-
+      //---
+      //--- Analyze the matrix
+      //---
+      const CoinPackedMatrix* m_matrix = milp.getMatrix();
       if (milp.m_param.BlockNumInput > 0) {
          milp.NumBlocks = milp.m_param.BlockNumInput;
          milp.m_param.Concurrent = false ;
          milp.m_param.NumBlocksCand = 0;
       }
-
-      blockNumberFinder(milp.m_param, blockNumCandidates, m_matrix);
+      if (milp.m_param.NumBlocksCand == 0) {
+	 blockNumberFinder(milp.m_param, blockNumCandidates, m_matrix);
+      }
       // obtain the number of CPU (core)s on machines with operating
       // system Linux, Solaris, & AIX and Mac OS X
       // (for all OS releases >= 10.4, i.e., Tiger onwards)
@@ -187,14 +195,14 @@ int main(int argc, char** argv)
 }
 
 /*
- *   Determining the candidate block numbers based on the instance fequency
+ *   Determining the candidate block numbers based on the instance frequency
  *     table
  */
-void blockNumberFinder(DecompParam utilParam,
+void blockNumberFinder(DecompParam decompParam,
                        std::vector<int>& blockNums,
                        const CoinPackedMatrix* matrix)
 {
-   if (utilParam.NumBlocksCand == 0) {
+   if (decompParam.NumBlocksCand == 0) {
       return ;
    }
 
@@ -216,9 +224,9 @@ void blockNumberFinder(DecompParam utilParam,
 
    std::map<int, int>::iterator histIter;
 
-   if (utilParam.LogDebugLevel >= 1) {
+   if (decompParam.LogDebugLevel >= 1) {
       std::ofstream histogramTable;
-      std::string path1 = utilParam.CurrentWorkingDir + UtilDirSlash() +
+      std::string path1 = decompParam.CurrentWorkingDir + UtilDirSlash() +
                           "histogramTable.dat";
       histogramTable.open(path1.c_str());
 
@@ -275,9 +283,9 @@ void blockNumberFinder(DecompParam utilParam,
       }
    }
 
-   if (utilParam.LogDebugLevel >= 1) {
+   if (decompParam.LogDebugLevel >= 1) {
       std::ofstream histogramTable1;
-      std::string path2 = utilParam.CurrentWorkingDir + UtilDirSlash() +
+      std::string path2 = decompParam.CurrentWorkingDir + UtilDirSlash() +
                           "histogramTable1.dat";
       histogramTable1.open(path2.c_str());
       std::map<int, int >::iterator histIter3;
@@ -290,7 +298,7 @@ void blockNumberFinder(DecompParam utilParam,
       histogramTable1.close();
    }
 
-   int blockCands = std::min(utilParam.NumBlocksCand - static_cast<int>
+   int blockCands = std::min(decompParam.NumBlocksCand - static_cast<int>
                              (blocksNumTemp.size()),
                              static_cast<int>(histogram2.size()));
 
@@ -306,7 +314,7 @@ void blockNumberFinder(DecompParam utilParam,
          }
       }
    } else {
-      int counter = utilParam.NumBlocksCand;
+      int counter = decompParam.NumBlocksCand;
       std::set<int>:: iterator setIter = blocksNumTemp.begin();
 
       while (counter) {
@@ -344,32 +352,26 @@ void DecompAuto(DecompApp milp,
    }
 
    //---
-   //--- put the one of the functions in the constructor into the main
+   //--- Initialize
    //---
-   milp.initializeApp(utilParam);
-   //      milp.startupLog();
+   milp.initializeApp();
+
    //---
    //--- create the algorithm (a DecompAlgo)
    //---
-   DecompAlgo* algo = NULL;
 
    if ((decompMainParam.doCut + decompMainParam.doPriceCut) != 1)
       throw UtilException("doCut or doPriceCut must be set",
                           "main", "main");
 
-   //assert(doCut + doPriceCut == 1);
    //---
-   //--- create the CPM algorithm object
+   //--- create the algorithm object
    //---
+   DecompAlgo* algo = NULL;
    if (decompMainParam.doCut) {
-      algo = new DecompAlgoC(&milp, &utilParam);
-   }
-
-   //---
-   //--- create the PC algorithm object
-   //---
-   if (decompMainParam.doPriceCut) {
-      algo = new DecompAlgoPC(&milp, &utilParam);
+      algo = new DecompAlgoC(&milp, utilParam);
+   }else{
+      algo = new DecompAlgoPC(&milp, utilParam);
    }
 
    if (decompMainParam.doCut && decompMainParam.doDirect) {
@@ -457,7 +459,8 @@ void DecompAuto(DecompApp milp,
            << UtilDblToStr(alpsModel.getGlobalUB(), 5) << endl
            << "OptiGap       = " << setw(10)
            << UtilDblToStr(UtilCalculateGap(alpsModel.getGlobalLB(),
-                                            alpsModel.getGlobalUB()), 5)
+                                            alpsModel.getGlobalUB(),
+					    milp.getDecompAlgo()->getInfinity()), 5)
            << endl
            << "Nodes         = "
            << alpsModel.getNumNodesProcessed() << endl
@@ -565,6 +568,7 @@ void DecompAuto(DecompApp milp,
       delete algo;
    }
 }
+
 DecompSolverResult* solveDirect(const DecompApp& decompApp)
 {
    //---
@@ -573,7 +577,39 @@ DecompSolverResult* solveDirect(const DecompApp& decompApp)
    //--- this function is created such that the DIP can serves
    //--- as an interface to call standalone branch-and-cut solver
    //---
-   OsiSolverInterface* m_problemSI = new OsiIpSolverInterface();
+
+   OsiSolverInterface *m_problemSI;
+
+   if (decompApp.m_param.DecompIPSolver == "SYMPONY"){
+#ifdef DIP_HAS_CLP
+      m_problemSI = new OsiSymSolverInterface();
+#else
+      throw UtilException("SYMPHONY selected as solver, but it's not available",
+			  "getOsiIpSolverInterface", "DecompAlgo");
+#endif
+   }else if (decompApp.m_param.DecompIPSolver == "Cbc"){
+#ifdef DIP_HAS_CLP
+      m_problemSI = new OsiCbcSolverInterface();
+#else
+      throw UtilException("Cbc selected as solver, but it's not available",
+			  "getOsiIpSolverInterface", "DecompAlgo");
+#endif
+   }else if (decompApp.m_param.DecompIPSolver == "CPLEX"){
+#ifdef DIP_HAS_CPX
+      m_problemSI = new OsiCpxSolverInterface();
+#else
+      throw UtilException("CPLEX selected as solver, but it's not available",
+			  "getOsiIpSolverInterface", "DecompAlgo");
+#endif
+   }else if (decompApp.m_param.DecompIPSolver == "Gurobi"){
+#ifdef DIP_HAS_GRB
+      m_problemSI = new OsiGrbSolverInterface();
+#else
+      throw UtilException("Gurobi selected as solver, but it's not available",
+			  "getOsiIpSolverInterface", "DecompAlgo");
+#endif
+   }
+
    string fileName;
 
    if (decompApp.m_param.DataDir != "") {
@@ -599,147 +635,157 @@ DecompSolverResult* solveDirect(const DecompApp& decompApp)
    m_problemSI->readMps(fileName.c_str());
    int numCols    = decompApp.m_mpsIO.getNumCols();
    int nNodes;
-   double objLB   = -DecompInf;
-   double objUB   = DecompInf;
-   double timeLimit = decompApp.m_param.LimitTime;
+   double objLB   = -m_problemSI->getInfinity();
+   double objUB   = m_problemSI->getInfinity();
+   double timeLimit = decompApp.m_param.TimeLimit;
    UtilTimer timer;
    timer.start();
-   DecompSolverResult* result = new DecompSolverResult();
-#ifdef __DECOMP_IP_CBC__
-   CbcModel cbc(*m_problemSI);
-   int logIpLevel = decompApp.m_param.LogIpLevel;
-   cbc.setLogLevel(logIpLevel);
-   cbc.setDblParam(CbcModel::CbcMaximumSeconds, timeLimit);
-   cbc.branchAndBound();
-   const int statusSet[2] = {0, 1};
-   int       solStatus    = cbc.status();
-   int       solStatus2   = cbc.secondaryStatus();
-
-   if (!UtilIsInSet(solStatus, statusSet, 2)) {
-      cerr << "Error: CBC IP solver status = "
-           << solStatus << endl;
-      throw UtilException("CBC solver status", "solveDirect", "solveDirect");
-   }
-
-   //---
-   //--- get number of nodes
-   //---
-   nNodes = cbc.getNodeCount();
-   //---
-   //--- get objective and solution
-   //---
-   objLB = cbc.getBestPossibleObjValue();
-
-   if (cbc.isProvenOptimal() || cbc.isSecondsLimitReached()) {
-      objUB = cbc.getObjValue();
-
-      if (result && cbc.getSolutionCount()) {
-         const double* solDbl = cbc.getColSolution();
-         vector<double> solVec(solDbl, solDbl + numCols);
-         result->m_solution.push_back(solVec);
-         result->m_nSolutions++;
-         assert(result->m_nSolutions ==
-                static_cast<int>(result->m_solution.size()));
-         //copy(solution, solution+numCols, result->m_solution);
+   DecompSolverResult* result = new DecompSolverResult(m_problemSI->getInfinity());
+   if (decompApp.m_param.DecompIPSolver == "Cbc"){
+#ifdef DIP_HAS_CBC
+      CbcModel cbc(*m_problemSI);
+      int logIpLevel = decompApp.m_param.LogIpLevel;
+      cbc.setLogLevel(logIpLevel);
+      cbc.setDblParam(CbcModel::CbcMaximumSeconds, timeLimit);
+      cbc.branchAndBound();
+      const int statusSet[2] = {0, 1};
+      int       solStatus    = cbc.status();
+      int       solStatus2   = cbc.secondaryStatus();
+      
+      if (!UtilIsInSet(solStatus, statusSet, 2)) {
+	 cerr << "Error: CBC IP solver status = "
+	      << solStatus << endl;
+	 throw UtilException("CBC solver status", "solveDirect", "solveDirect");
       }
-   }
-
-   //---
-   //--- copy sol status into result
-   //---
-   if (result) {
-      result->m_solStatus  = solStatus;
-      result->m_solStatus2 = solStatus2;
-   }
-
-#endif
-#ifdef __DECOMP_IP_CPX__
-   OsiIpSolverInterface* masterSICpx
-   = dynamic_cast<OsiCpxSolverInterface*>(m_problemSI);
-   CPXLPptr  cpxLp  = masterSICpx->getLpPtr();
-   CPXENVptr cpxEnv = masterSICpx->getEnvironmentPtr();
-   int       status = 0;
-   masterSICpx->switchToMIP();//need?
-   //---
-   //--- set the time limit
-   //---
-   status = CPXsetdblparam(cpxEnv, CPX_PARAM_TILIM, timeLimit);
-   //---
-   //--- set the thread limit, otherwise CPLEX will use all the resources
-   //---
-   status = CPXsetintparam(cpxEnv, CPX_PARAM_THREADS,
-                           decompApp.m_param.NumThreadsIPSolver);
-
-   if (status)
-      throw UtilException("CPXsetdblparam failure",
-                          "solveDirect", "DecompAlgoC");
-
-   //---
-   //--- solve the MILP
-   //---
-   UtilTimer timer1;
-   timer1.start();
-   masterSICpx->branchAndBound();
-   timer1.stop();
-   cout << "just after solving" << endl;
-   cout << " Real=" << setw(10) << UtilDblToStr(timer1.getRealTime(), 5)
-        << " Cpu= " << setw(10) << UtilDblToStr(timer1.getCpuTime() , 5);
-   //---
-   //--- get solver status
-   //---
-   //---
-   int solStatus = CPXgetstat(cpxEnv, cpxLp);
-
-   if (result) {
-      result->m_solStatus  = solStatus;
-      result->m_solStatus2 = 0;
-   }
-
-   //---
-   //--- get number of nodes
-   //---
-   nNodes  = CPXgetnodecnt(cpxEnv, cpxLp);
-   //---
-   //--- get objective and solution
-   //---
-   status = CPXgetbestobjval(cpxEnv, cpxLp, &objLB);
-
-   if (status)
-      throw UtilException("CPXgetbestobjval failure",
-                          "solveDirect", "DecompAlgoC");
-
-   //---
-   //--- get objective and solution
-   //---
-   if (solStatus == CPXMIP_OPTIMAL     ||
-         solStatus == CPXMIP_OPTIMAL_TOL ||
-         solStatus == CPXMIP_TIME_LIM_FEAS) {
-      status = CPXgetmipobjval(cpxEnv, cpxLp, &objUB);
-
-      if (status)
-         throw UtilException("CPXgetmipobjval failure",
-                             "solveDirect", "DecompAlgoC");
-
+      
+      //---
+      //--- get number of nodes
+      //---
+      nNodes = cbc.getNodeCount();
+      //---
+      //--- get objective and solution
+      //---
+      objLB = cbc.getBestPossibleObjValue();
+      
+      if (cbc.isProvenOptimal() || cbc.isSecondsLimitReached()) {
+	 objUB = cbc.getObjValue();
+	 
+	 if (result && cbc.getSolutionCount()) {
+	    const double* solDbl = cbc.getColSolution();
+	    vector<double> solVec(solDbl, solDbl + numCols);
+	    result->m_solution.push_back(solVec);
+	    result->m_nSolutions++;
+	    assert(result->m_nSolutions ==
+		   static_cast<int>(result->m_solution.size()));
+	    //copy(solution, solution+numCols, result->m_solution);
+	 }
+      }
+      
+      //---
+      //--- copy sol status into result
+      //---
       if (result) {
-         const double* solDbl = masterSICpx->getColSolution();
-         vector<double> solVec(solDbl, solDbl + numCols);
-         result->m_solution.push_back(solVec);
-         result->m_nSolutions++;
-         assert(result->m_nSolutions ==
-                static_cast<int>(result->m_solution.size()));
-         //copy(solution, solution+numCols, result->m_solution);
+	 result->m_solStatus  = solStatus;
+	 result->m_solStatus2 = solStatus2;
       }
-   }
-
-   //---
-   //--- copy sol status into result
-   //---
-   if (result) {
-      result->m_solStatus  = solStatus;
-      result->m_solStatus2 = 0;
-   }
-
+#else
+      throw UtilException("Cbc selected as solver, but it's not available",
+			  "solveDirect", "DecompMain");
 #endif
+   }else if (decompApp.m_param.DecompIPSolver == "CPLEX"){
+#ifdef DIP_HAS_CPX
+      OsiCpxSolverInterface* masterSICpx
+	 = dynamic_cast<OsiCpxSolverInterface*>(m_problemSI);
+      CPXLPptr  cpxLp  = masterSICpx->getLpPtr();
+      CPXENVptr cpxEnv = masterSICpx->getEnvironmentPtr();
+      int       status = 0;
+      masterSICpx->switchToMIP();//need?
+      //---
+      //--- set the time limit
+      //---
+      status = CPXsetdblparam(cpxEnv, CPX_PARAM_TILIM, timeLimit);
+      //---
+      //--- set the thread limit, otherwise CPLEX will use all the resources
+      //---
+      status = CPXsetintparam(cpxEnv, CPX_PARAM_THREADS,
+			      decompApp.m_param.NumThreadsIPSolver);
+      
+      if (status)
+	 throw UtilException("CPXsetdblparam failure",
+			     "solveDirect", "DecompAlgoC");
+      
+      //---
+      //--- solve the MILP
+      //---
+      UtilTimer timer1;
+      timer1.start();
+      masterSICpx->branchAndBound();
+      timer1.stop();
+      cout << "just after solving" << endl;
+      cout << " Real=" << setw(10) << UtilDblToStr(timer1.getRealTime(), 5)
+	   << " Cpu= " << setw(10) << UtilDblToStr(timer1.getCpuTime() , 5);
+      //---
+      //--- get solver status
+      //---
+      //---
+      int solStatus = CPXgetstat(cpxEnv, cpxLp);
+      
+      if (result) {
+	 result->m_solStatus  = solStatus;
+	 result->m_solStatus2 = 0;
+      }
+      
+      //---
+      //--- get number of nodes
+      //---
+      nNodes  = CPXgetnodecnt(cpxEnv, cpxLp);
+      //---
+      //--- get objective and solution
+      //---
+      status = CPXgetbestobjval(cpxEnv, cpxLp, &objLB);
+      
+      if (status)
+	 throw UtilException("CPXgetbestobjval failure",
+			     "solveDirect", "DecompAlgoC");
+      
+      //---
+      //--- get objective and solution
+      //---
+      if (solStatus == CPXMIP_OPTIMAL     ||
+	  solStatus == CPXMIP_OPTIMAL_TOL ||
+	  solStatus == CPXMIP_TIME_LIM_FEAS) {
+	 status = CPXgetmipobjval(cpxEnv, cpxLp, &objUB);
+	 
+	 if (status)
+	    throw UtilException("CPXgetmipobjval failure",
+				"solveDirect", "DecompAlgoC");
+	 
+	 if (result) {
+	    const double* solDbl = masterSICpx->getColSolution();
+	    vector<double> solVec(solDbl, solDbl + numCols);
+	    result->m_solution.push_back(solVec);
+	    result->m_nSolutions++;
+	    assert(result->m_nSolutions ==
+		   static_cast<int>(result->m_solution.size()));
+	    //copy(solution, solution+numCols, result->m_solution);
+	 }
+      }
+      
+      //---
+      //--- copy sol status into result
+      //---
+      if (result) {
+	 result->m_solStatus  = solStatus;
+	 result->m_solStatus2 = 0;
+      }
+#else
+      throw UtilException("CPLEX selected as solver, but it's not available",
+			  "solveDirect", "DecompMain");
+#endif
+   }else{
+      throw UtilException("solveDirect not implemented for selected solver",
+			  "solveDirect", "DecompDebug");
+   }
 
    //---
    //--- copy bounds into result
