@@ -34,6 +34,27 @@ class DipError(Exception):
     """
     Dip Exception
     """
+	
+# DIP solver status
+#enum DecompSolverStatus {
+#   DecompSolStatError,
+#   DecompSolStatOptimal,
+#   DecompSolStatFeasible,
+#   DecompSolStatInfeasible,
+#   DecompSolStatNoSolution
+#};
+DipSolStatError      = 0
+DipSolStatOptimal    = 1
+DipSolStatFeasible   = 2
+DipSolStatInfeasible = 3
+DipSolStatNoSolution = 4
+DipStatus = {
+             DipSolStatError:      "Error",
+             DipSolStatOptimal:    "Optimal",
+             DipSolStatFeasible:   "Feasible",
+             DipSolStatInfeasible: "Infeasible",
+             DipSolStatNoSolution: "No solution"
+            }
 
 _Solve = Solve
 def Solve(prob, params=None):
@@ -444,12 +465,14 @@ class DipProblem(pulp.LpProblem, DipAPI):
         b.write("%i\n" % len(self.relaxation.dict))
         for k in self.constraints:
             f.write(self.constraints[k].asCplexLpConstraint(k))
+        blockId = 0
         for r in self.relaxation.dict:
             rname = asCplexName(str(r))
-            b.write("BLOCK %s\n" % rname)
+            b.write("BLOCK %d\n" % blockId) 
             for k in self.relaxation.dict[r].constraints:
                 f.write(self.relaxation.dict[r].constraints[k].asCplexLpConstraint(str(k)+'_'+rname))
                 b.write(str(k)+'_'+rname+'\n')
+            blockId += 1
         vs = list(self.variables())
         # check if any names are longer than 100 characters
         long_names = [v.name for v in vs if len(v.name) > 100]
@@ -792,15 +815,20 @@ class DipProblem(pulp.LpProblem, DipAPI):
     def solveRelaxed(self, key, redCostX, target):
         """
         Returns solutions to the whichBlock relaxed subproblem
-
-        Inputs: 
+    
+        Inputs:  
         key (Python Object) = key of relaxed subproblem to be solved
-        redCostX (list of (LpVariable, value) tuples) = list of reduced costs
-
-        Output: 
-        varList (list of (cost, reduced cost, (LpVariable, value)
-        dictionaries)) = solution for this relaxed subproblem expressed as a
-        cost, reduced cost and dictionary of non-zero values for variables
+        redCostX (list of (variable, value) tuples) = list of reduced costs for all variables
+        target (float) = any total reduced cost less than the target is "good" (results in a negative cost column)
+    
+        Output:
+        status (integer) = status of the relaxation solve, will be one of
+          DipSolStatOptimal    = no better columns can be found
+          DipSolStatFeasible   = better columns can be found, but just use these for now
+          DipSolStatNoSolution = use any columns returned, but also use DIP's default column finder
+        varList (list of (cost, reduced cost, list of (variable, value) dictionaries)) =
+        solution for this relaxed subproblem expressed as a cost, reduced cost and
+        dictionary of non-zero values for variables
         """
         try:
           
@@ -814,23 +842,22 @@ class DipProblem(pulp.LpProblem, DipAPI):
                 raise DipError("Reduced cost and variable list don't match in",
                                "solveRelaxed")
     
-            dvs = self.relaxed_solver(self, key, redCostDict, target)
-            
-            if dvs is not None:
-                if len(dvs) > 0:
-                    dvs_with_costs = []
-                    for var in dvs:
-                        if isinstance(var, dict):
-                            cost = sum(self.objective[i]*var[i] for i in var
-                                       if i in self.objective)
-                            red_cost = sum(redCostDict[i]*var[i] for i in var
-                                           if i in redCostDict)
-                            dvs_with_costs.append((cost, red_cost, var))
-                        else:
-                            return dvs
-                    return dvs_with_costs
-                else:
-                    print "Empty variable list in solveRelaxed, returning None"
+            status, dvs = self.relaxed_solver(self, key, redCostDict, target)
+    
+            if len(dvs) > 0:
+                dvs_with_costs = []
+                for var in dvs:
+                    if isinstance(var, dict):
+                        cost = sum(self.objective[i]*var[i] for i in var
+                                   if i in self.objective)
+                        red_cost = sum(redCostDict[i]*var[i] for i in var
+                                       if i in redCostDict)
+                        dvs_with_costs.append((cost, red_cost, var))
+                    else:
+                        return status, dvs
+                return status, dvs_with_costs
+            else:
+                return status, dvs
   
         except Exception as ex:
             errorStr = "Error in solveRelaxed\n%s" % ex
